﻿using Hotline.Api.Token;
using Hotline.CallCenter.BlackLists;
using Hotline.Repository.SqlSugar;
using Hotline.Share.Requests;
using Hotline.Users;
using Microsoft.AspNetCore.Mvc;
using NETCore.Encrypt;
using SqlSugar;
using XF.Domain.Exceptions;

namespace Hotline.Api.Controllers;

public class HomeController : BaseController
{
    private readonly IUserRepository _userRepository;
    private readonly ISugarUnitOfWork<HotlineDbContext> _uow;

    public HomeController(IUserRepository userRepository, ISugarUnitOfWork<HotlineDbContext> uow)
    {
        _userRepository = userRepository;
        _uow = uow;
    }

    [HttpPost("login")]
    public async Task<string> Login([FromBody] LoginRequest request)
    {
        var user =
            await _userRepository.GetAsync(d => !d.IsDeleted && d.PhoneNo == request.PhoneNo, HttpContext.RequestAborted);
        if (user is null)
            throw new UserFriendlyException("未查询到该用户");

        var token = EncryptProvider.AESEncrypt(System.Text.Json.JsonSerializer.Serialize(user), Sercurity.Key);
        return token;
    }

    [HttpGet("createdb")]
    public Task CreateDb()
    {
        var db = _uow.Db;
        db.DbMaintenance.CreateDatabase();
        db.CodeFirst.InitTables<Blacklist>();

        return Task.CompletedTask;
    }
}